package com.zg.project.Inventory.Visualization.service;

import java.util.List;
import com.zg.project.Inventory.Visualization.domain.Odtl;
import com.zg.project.Inventory.Visualization.domain.vo.OdtlVO;

/**
 * 借料出库 明细Service接口
 * 
 * @author zg
 * @date 2025-05-09
 */
public interface IOdtlService 
{
    /**
     * 查询借料出库 明细
     * 
     * @param Id 借料出库 明细主键
     * @return 借料出库 明细
     */
    public Odtl selectOdtlById(Long Id);

    /**
     * 查询借料出库 明细列表
     * 
     * @param odtl 借料出库 明细
     * @return 借料出库 明细集合
     */
    public List<Odtl> selectOdtlList(Odtl odtl);

    /**
     * 新增借料出库 明细
     * 
     * @param odtl 借料出库 明细
     * @return 结果
     */
    public int insertOdtl(Odtl odtl);

    /**
     * 修改借料出库 明细
     * 
     * @param odtl 借料出库 明细
     * @return 结果
     */
    public int updateOdtl(Odtl odtl);

    /**
     * 批量删除借料出库 明细
     * 
     * @param Ids 需要删除的借料出库 明细主键集合
     * @return 结果
     */
    public int deleteOdtlByIds(Long[] Ids);

    /**
     * 删除借料出库 明细信息
     * 
     * @param Id 借料出库 明细主键
     * @return 结果
     */
    public int deleteOdtlById(Long Id);

    List<OdtlVO> queryAll();

}
